@@ -19,7 +19,7 @@ class hk_buttonmodeprivate;
 /**
  *
  *@short base class for a button in a form
- *@version $Revision: 1.25 $
+ *@version $Revision: 1.26 $
  *@author Horst Knorr (hk_classes@knoda.org)
  */
 class hk_button :public hk_dsvisible
@@ -87,7 +87,7 @@ virtual bool push_action(void);
         void set_database(hk_database* database);
         hk_database* database(void);
 
-        virtual void loaddata(const hk_string& definition);
+        virtual void loaddata(xmlNodePtr definition);
         virtual void  savedata(ostream& s );
 
         typedef class
