@@ -117,7 +117,10 @@ void hk_colour::savedata(ostream& s )
 }
 
 
-void hk_colour::loaddata(const hk_string& definition)
+
+
+
+void hk_colour::loaddata(xmlNodePtr definition)
 {
     get_tagvalue(definition,"RED",p_red);
     get_tagvalue(definition,"GREEN",p_green);
