@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.117 $
+//$Revision: 1.126 $
 #include "hk_database.h"
 #include "hk_data.h"
 #include "hk_dbvisible.h"
@@ -102,6 +102,14 @@ bool hk_database::set_name(const hk_string& n)
     hkdebug("hk_database::set_name");
 #endif
     hk_string nm=trim(n);
+    if (!p_connection->server_supports(hk_connection::SUPPORTS_LOCAL_FILEFORMAT))
+    {
+      hk_url u=nm;
+      if (u.directory().size()>0)
+      nm=u.filename();
+      if (u.extension().size()>0)
+       nm="_"+u.extension();
+    }
     if (nm==p_private->p_dbname)return true;
     hk_string oldname=p_private->p_dbname;
     p_private->p_dbname=nm;
@@ -354,6 +362,10 @@ bool hk_database::select_db(const hk_string& newname)
     if (p_connection->is_connected())
     {
         p_private->p_dbname=newname;
+	
+	if (p_connection->server_needs(hk_connection::NEEDS_DIRECTORY_AS_DATABASE))
+	p_url=newname;//+"/";
+	else
 	p_url=newname;
         bool erg= driver_specific_select_db();
         if (erg)
@@ -381,10 +393,13 @@ bool hk_database::select_db(const hk_string& newname)
             mkdir (b.c_str(),S_IRUSR|S_IWUSR|S_IXUSR);
 	    if (has_centralstoragetable())
 	    {
-	     for (int f=ft_query;f<=ft_report;++f)
+	     for (int f=ft_query;f<=ft_module;++f)
 	      {
+		    if (f!=ft_view)
+		    {
 		    p_private->p_storagemode[f]=hk_database::central;
 		    p_private->p_loadmode[f]=hk_database::central;
+		    }
 	      }
 
 	    }
@@ -704,6 +719,7 @@ hk_datasource* ds=new_table("HKCLASSES");
                     if (type==ft_query)dialog=hk_translate("Enter new query name:");
                     else if (type==ft_form)dialog=hk_translate("Enter new form name:");
                     else if (type==ft_report)dialog=hk_translate("Enter new report name:");
+                    else if (type==ft_module)dialog=hk_translate("Enter new module name:");
                     else dialog=hk_translate("Enter new name:");
                     hk_string res=show_stringvaluedialog(dialog);
                     if (res.size()==0)
@@ -759,6 +775,7 @@ hk_string hk_database::savemessage(filetype type,enum_storage storage,hk_string
     if (type==ft_query)dialog=replace_all("%1",hk_translate("Query '%1' already exists. Overwrite it?"),nm);
     else if (type==ft_form)dialog=replace_all("%1",hk_translate("Form '%1' already exists. Overwrite it?"),nm);
     else if (type==ft_report)dialog=replace_all("%1",hk_translate("Report '%1' already exists. Overwrite it?"),nm);
+    else if (type==ft_module)dialog=replace_all("%1",hk_translate("Module '%1' already exists. Overwrite it?"),nm);
     else dialog=replace_all("%1",hk_translate("File '%1' already exists. Overwrite it?"),nm);
  }
  else
@@ -766,6 +783,7 @@ hk_string hk_database::savemessage(filetype type,enum_storage storage,hk_string
     if (type==ft_query)dialog=replace_all("%1",hk_translate("Query '%1' has changed. Store changes?"),nm);
     else if (type==ft_form)dialog=replace_all("%1",hk_translate("Form '%1' has changed. Store changes?"),nm);
     else if (type==ft_report)dialog=replace_all("%1",hk_translate("Report '%1' has changed. Store changes?"),nm);
+    else if (type==ft_module)dialog=replace_all("%1",hk_translate("Module '%1' has changed. Store changes?"),nm);
     else dialog=replace_all("%1",hk_translate("File '%1' has changed. Store changes?"),nm);
  }
  return dialog;
@@ -783,8 +801,9 @@ ofstream* hk_database::savestream(enum_storage storage,const hk_string&nm,filety
     hkdebug("hk_database::savestream");
 #endif
     hk_string filename=p_private->p_databasepath+"/";
-    filename+=nm+fileendings(type);
-    hk_string dialog=savemessage(type,storage,nm);
+    hk_url url(nm);
+    filename+=url.filename()+(url.extension().size()>0?"."+url.extension():"")+fileendings(type);
+    hk_string dialog=savemessage(type,storage,url.filename());
     
     if (ask_before_overwrite)
     {
@@ -800,6 +819,7 @@ ofstream* hk_database::savestream(enum_storage storage,const hk_string&nm,filety
                     if (type==ft_query)dialog=hk_translate("Enter new query name:");
                     else if (type==ft_form)dialog=hk_translate("Enter new form name:");
                     else if (type==ft_report)dialog=hk_translate("Enter new report name:");
+                    else if (type==ft_module)dialog=hk_translate("Enter new module name:");
                     else dialog=hk_translate("Enter new name:");
                     hk_string res=show_stringvaluedialog(dialog);
                     if (res.size()==0) return NULL;
@@ -879,6 +899,15 @@ ofstream* hk_database::savestream(enum_storage storage,const hk_string&nm,filety
 
 
 
+xmlNodePtr hk_database::xmlload(const hk_string& nm,filetype type)
+{
+#ifdef HK_DEBUG
+    hkdebug("hk_database::xmlload");
+#endif
+return (p_private->p_loadmode[type]==central?xmlload_central(nm,type):xmlload_local(nm,type));
+}
+
+
 hk_string hk_database::load(const hk_string& nm,filetype type)
 {
 #ifdef HK_DEBUG
@@ -888,6 +917,79 @@ return (p_private->p_loadmode[type]==central?load_central(nm,type):load_local(nm
 }
 
 
+xmlNodePtr hk_database::xmlload_local(const hk_string& nm,filetype type)
+{
+#ifdef HK_DEBUG
+    hkdebug("hk_database::load_local");
+#endif
+    if (nm.size()==0) return NULL;
+    hk_string n=p_private->p_databasepath+"/";
+    n+=nm+fileendings(type);
+    xmlDocPtr d= xmlParseFile(n.c_str());
+    return xmlDocGetRootElement(d);
+}
+
+
+xmlNodePtr hk_database::xmlload_central(const hk_string& nm,filetype type)
+{
+#ifdef HK_DEBUG
+    hkdebug("hk_database::load_central");
+#endif
+
+hk_datasource* ds=new_table("HKCLASSES");
+ if (!ds)
+   {
+   show_warningmessage(hk_translate("Error: hk_database::load_central could not get a new table"));
+   return NULL;
+   }
+ hk_string result;
+ hk_string filter="\"type\"="+longint2string(type);
+ ds->set_filter(filter);
+ ds->enable();
+ hk_column* n=ds->column_by_name("name");
+ hk_column* v=ds->column_by_name("value");
+ hk_column* t=ds->column_by_name("type");
+ if (!n ||!v||!t)
+   {
+    show_warningmessage(hk_translate("Error: hk_database::load_central could not find system columns!"));
+    delete ds;
+    return NULL;
+   }
+  unsigned int row=n->find(nm,true,true);
+  if (row > ds->max_rows())
+  { // not existing
+     /*show_warningmessage(replace_all("%1",hk_translate("Error: hk_database::load_central object '%1' not found"),name));*/
+     //cerr <<"no file: "<<n<<endl;
+     delete ds;
+     return NULL;
+  }
+  else
+  {  // replace existing object
+    ds->goto_row(row);
+  }
+  result=v->asstring();
+  delete ds;
+xmlDocPtr d= xmlParseMemory(result.c_str(),result.size());
+return xmlDocGetRootElement(d);
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 hk_string hk_database::load_local(const hk_string& nm,filetype type)
 {
 #ifdef HK_DEBUG
@@ -967,6 +1069,7 @@ hk_string hk_database::fileendings(filetype e)
         case ft_form: return ".hk_form";
         case ft_report: return ".hk_report";
         case ft_view: return ".hk_view";
+        case ft_module: return ".hk_module";
         case ft_referentialintegrity: return ".hk_referentialintegrity";
     }
     return ".hk_unknown";
@@ -982,6 +1085,7 @@ hk_string hk_database::fileendings(objecttype e)
      case ot_query: f=ft_query;break;
      case ot_form: f=ft_form;break;
      case ot_report: f=ft_report;break;
+     case ot_module: f=ft_module;break;
      default: return ".hk_unknown";
    }
    return fileendings(f);
@@ -1005,6 +1109,12 @@ vector<hk_string>* hk_database::reportlist(void)
     return filelist(ft_report);
 }
 
+vector<hk_string>* hk_database::modulelist(void)
+{
+    return filelist(ft_module);
+}
+
+
 
 
 vector<hk_string>* hk_database::filelist(filetype type)
@@ -1024,6 +1134,7 @@ vector<hk_string>* hk_database::central_filelist(filetype type)
     hkdebug("hk_database::central_filelist");
 #endif
  p_private->p_filelist.erase(p_private->p_filelist.begin(),p_private->p_filelist.end());
+if (!p_connection->server_supports(hk_connection::SUPPORTS_SQL)) return &p_private->p_filelist;
  if (!has_centralstoragetable() || !p_connection->is_connected()) return &p_private->p_filelist;
  hk_datasource* ds=new_resultquery();
  if (!ds)
@@ -1040,11 +1151,13 @@ vector<hk_string>* hk_database::central_filelist(filetype type)
    type 2 = query
    type 3 = form
    type 4 = report
+   type 7 = module
  */
         case ft_table:  t="1";break;
         case ft_query:  t="2";break;
         case ft_form:   t="3";break;
         case ft_report: t="4";break;
+        case ft_module: t="7";break;
         default :
 	   {
 	     show_warningmessage(hk_translate("Warning: hk_database::central_filelist, unknown filetype"));
@@ -1093,12 +1206,12 @@ vector<hk_string>* hk_database::local_filelist(filetype type)
         while ((entry = readdir(dp))!=NULL)
         {
             datei=entry->d_name;
-            size_t p =datei.find(fileend);
-            if (p<datei.size())
-            {
-                datei.replace(p,datei.size()-p,"");
-                p_private->p_filelist.insert(p_private->p_filelist.end(),datei);
-            }
+            hk_url url(entry->d_name);
+            if ("."+url.extension()==fileend)
+             {
+                p_private->p_filelist.insert(p_private->p_filelist.end(),url.filename());
+             
+             }
         }
         closedir(dp);
 
@@ -1122,6 +1235,9 @@ bool  hk_database::delete_file(const hk_string& nm,filetype type,enum_interactio
     else
     if (type==ft_form)
         message=hk_translate("Delete the form:%FNAME%?");
+    else
+    if (type==ft_module)
+        message=hk_translate("Delete the module:%FNAME%?");
     else
         message=hk_translate("Delete the file:%FNAME%");
     message=replace_all("%FNAME%",message,nm);
@@ -1238,12 +1354,12 @@ hk_datasource*  hk_database::load_datasource(const hk_string& nm,datasourcetype
     {
         hk_datasource* d=NULL;
 	if (nm.size()==0) return new_resultquery(p);
-        hk_string r=load(nm,ft_query);
-        if (r.size()>0)
+        xmlNodePtr r=xmlload(nm,ft_query);
+        if (r)
         {
             d=new_resultquery(p);
         }
-        if (d!=NULL) d->loaddata(u2l(r));
+        if (d!=NULL) d->loaddata(r);
         return d;
     }
     case dt_view:
@@ -1464,7 +1580,9 @@ bool hk_database::copy_table(hk_datasource* fromdatasource,bool schema_and_data,
             char c;
         while (stream.get(c))
             structure+=c;
-    bool result=newds->load_datasourcedefinition(u2l(structure),replacetable);
+    xmlDocPtr d=xmlParseMemory(structure.c_str(),structure.size());
+    xmlNodePtr node=xmlDocGetRootElement(d);           
+    bool result=newds->load_datasourcedefinition(node,replacetable);
     bool cancel=false;
     if (result&&schema_and_data)
     {
@@ -1836,7 +1954,7 @@ bool hk_database::rename_file(const hk_string& originalname, const hk_string& ne
 
 void hk_database::set_storagemode(filetype type,enum_storagemode loadmd,enum_storagemode storemd)
 {
-   if (type>ft_report) return;
+   if (type==ft_referentialintegrity || type==ft_view) return;
    bool hascentraltable =has_centralstoragetable();
       p_private->p_loadmode[type]=((hascentraltable && loadmd==hk_database::central)?
                              hk_database::central:hk_database::local
@@ -1930,13 +2048,13 @@ void hk_database::load_configuration(void)
 #endif
     hk_string n=database_path()+"/";
     n+="database.conf";
-    hk_string result;
-    ifstream ifs(n.c_str(),ios::in);
-    if (ifs)
+    if (!file_exists(n)) return;
+    xmlDocPtr doc=xmlParseFile(n.c_str());
+    xmlNodePtr result=NULL;
+    if (doc) result=xmlDocGetRootElement(doc);
+
+    if (doc && result)
     {
-        char c;
-        while (ifs.get(c))
-            result+=c;
         loaddata(result);
 
     }
@@ -1965,8 +2083,10 @@ void hk_database::savedata(ostream& s)
     hk_string mt="DATABASE";
     s<<"<?xml version=\"1.0\" ?>"<<endl;
     start_mastertag(s,mt);
-    for (int f=ft_query;f<=ft_report;++f)
-        save_storage(s,(filetype)f);
+        save_storage(s,ft_query);
+        save_storage(s,ft_form);
+        save_storage(s,ft_report);
+        save_storage(s,ft_module);
     set_tagvalue(s,"DATABASECHARSET",p_private->p_charset);
     set_tagvalue(s,"AUTOMATIC_DATA_UPDATE",is_automatic_data_update());
     
@@ -1998,12 +2118,17 @@ void hk_database::save_storage(ostream& s,filetype f)
      			savetxt="STOREVIEW";
 			loadtxt="LOADVIEW";
      			break;
+     case ft_module:
+     			savetxt="STOREMODULE";
+			loadtxt="LOADMODULE";
+     			break;
      case ft_referentialintegrity:
      			savetxt="STOREREFERENTIALINTEGRITY";
 			loadtxt="LOADREFERENTIALINTEGRITY";
      			break;
 
     };
+//     cerr <<"f:"<<f<<" savetxt:"<<savetxt<<" loadtxt:"<<loadtxt<<endl;
     hk_string c=(p_private->p_storagemode[f]==hk_database::local?"LOCAL":"CENTRAL");
     set_tagvalue(s,savetxt,c);
     c=(p_private->p_loadmode[f]==hk_database::local?"LOCAL":"CENTRAL");
@@ -2011,7 +2136,8 @@ void hk_database::save_storage(ostream& s,filetype f)
 
 }
 
-void hk_database::loaddata(const hk_string& definition)
+
+void hk_database::loaddata(xmlNodePtr definition)
 {
     get_tagvalue(definition,"DATABASECHARSET",p_private->p_charset);
     get_tagvalue(definition,"AUTOMATIC_DATA_UPDATE",p_private->p_automatic_data_update);
@@ -2024,14 +2150,14 @@ void hk_database::loaddata(const hk_string& definition)
      }
     return;
    }
-    for (int f=ft_query;f<=ft_report;++f)
+    for (int f=ft_query;f<=ft_module;++f)
     {
     load_storage(definition,(filetype)f);
     }
 
 }
 
-void hk_database::load_storage(const hk_string& definition,filetype f)
+void hk_database::load_storage(xmlNodePtr definition,filetype f)
 {
 
     hk_string savetxt,loadtxt;
@@ -2057,6 +2183,10 @@ void hk_database::load_storage(const hk_string& definition,filetype f)
      			savetxt="STOREVIEW";
 			loadtxt="LOADVIEW";
      			break;
+     case ft_module:
+     			savetxt="STOREMODULE";
+			loadtxt="LOADMODULE";
+     			break;
      case ft_referentialintegrity:
      			savetxt="STOREREFERENTIALINTEGRITY";
 			loadtxt="LOADREFERENTIALINTEGRITY";
@@ -2096,6 +2226,8 @@ bool hk_database::store_connectionfile(const hk_url& url, bool store_password)
     if (stream!=NULL &&!stream->fail())
 	{
         (*stream) <<"<?xml version=\"1.0\" encoding=\"UTF-8\" ?>"<<endl;
+ hk_string mtag="STOREDCONNECTION";
+ start_mastertag(*stream,mtag);
  set_tagvalue(*stream,"CONNECTION",p_connection->drivername());
  set_tagvalue(*stream,"DATABASE",name());
  set_tagvalue(*stream,"USER",p_connection->user());
@@ -2103,6 +2235,7 @@ bool hk_database::store_connectionfile(const hk_url& url, bool store_password)
  set_tagvalue(*stream,"HOST",p_connection->host());
  set_tagvalue(*stream,"TCPPORT",p_connection->tcp_port());
  set_tagvalue(*stream,"BOOLEANEMULATION",p_connection->booleanemulation());
+ end_mastertag(*stream,mtag);
 
 	}
     delete stream;
