@@ -27,7 +27,7 @@ class hk_datasourceprivate;
 /**
  *
  *@short  represents a resultquery or a table of a database.
- *@version $Revision: 1.98 $
+ *@version $Revision: 1.102 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *hk_datasource is the basic class which represents a resultquery or a table of a database.
@@ -497,7 +497,7 @@ See also @ref set_depending_on for details
 /**
  *loads the object's values out of the definition string.
  */
-        void  loaddata(const hk_string& definition,bool loadsql=true);
+        void  loaddata(xmlNodePtr definition,bool loadsql=true);
 /**
  *  stores the datasource as a query file
  *@return true if successful else false
@@ -576,7 +576,7 @@ virtual        bool delete_rows(unsigned long from,unsigned long to,bool check_d
 /**
  *loads the structure of the datasource (fields,indices) in an xml format file and creates the tableand is database driver independent
  */
-        bool load_datasourcedefinition(const hk_string& definition,bool use_xmltablename=true ,bool ask=true);
+        bool load_datasourcedefinition(xmlNodePtr definition,bool use_xmltablename=true ,bool ask=true);
 hk_presentation* presentation(void);
 /**
 *the position will be used for the database designer GUI. Mostly you don't have to manipulate the values
@@ -624,6 +624,10 @@ static void set_enablefunction(voidfunction*, long counter);
         bool   depending_on_datasource_before_delete_row(void);
         bool   depending_on_datasource_updaterow_ok(void);
         bool check_store_changed_data();
+        void set_progressdialog(progress_dialogtype* progressdialog);
+        progress_dialogtype* progressdialog(void)const;
+        void set_progressinterval(int);
+        int progressinterval(void) const;
 
     
     
@@ -835,6 +839,7 @@ static void set_enablefunction(voidfunction*, long counter);
         list<referentialclass> p_references;
 	hk_string new_referencename(const referentialclass&);
 	bool is_newreferencename(const hk_string&);
+	hk_string replace_dates(const hk_string&);
 
     private:
         hk_string   p_original_sql;
