@@ -8,11 +8,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.10 $
+//$Revision: 1.11 $
 #include "hk_dsboolean.h"
 #include "hk_form.h"
 
-hk_dsboolean::hk_dsboolean(hk_form* form):hk_dsdatavisible(form)
+hk_dsboolean::hk_dsboolean(hk_form* f):hk_dsdatavisible(f)
 {
     p_visibletype=boolean;
     p_gridcolumn=NULL;
