@@ -19,7 +19,7 @@ class hk_dscomboboxmodeprivate;
 /**
  *
  *@short  base class for combobox fields
- *@version $Revision: 1.22 $
+ *@version $Revision: 1.24 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *base class for combobox fields
@@ -55,7 +55,7 @@ virtual        ~hk_dscombobox();
         void    set_listcolumnname(const hk_string& listcolumn,bool registerchange=true);
         hk_string listcolumnname(void);
         virtual void savedata(ostream& s );
-        virtual void loaddata(const hk_string& definition);
+        virtual void loaddata(xmlNodePtr definition);
 /**
  *if this combobox is part of a hk_presentation object (i.e. a  form) you can set the listdatasource by its unique presentation number
  */
@@ -101,6 +101,7 @@ void set_on_select_action(const hk_string&,bool registerchange=true,bool force_s
     //needed for gridcolumn actions where a line editor takes the input (eg. action_on_key)
     hk_dsgridcolumn* p_gridcolumn;
     private:
+        void create_filternames();
         hk_listvisible* p_listvisible;
         long p_listdatasource;
         enum_mode p_mode;
