@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.59 $
+//$Revision: 1.62 $
 #include "hk_dsgrid.h"
 #include "hk_form.h"
 #include "hk_column.h"
@@ -219,12 +219,15 @@ void  hk_dsgrid::savedata(ostream& s,bool saveall)
 }
 
 
-void hk_dsgrid::loaddata(const hk_string& definition)
+void hk_dsgrid::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_dsgrid::loaddata");
 #endif
-    hk_dsvisible::loaddata(definition);
+    xmlNodePtr d=get_tagvalue(definition,"HK_DSVISIBLE");
+    if (d)d=d->xmlChildrenNode;
+
+    hk_dsvisible::loaddata(d);
     if (get_tagvalue(definition,"ROWHEIGHT",p_rowheight))
        {
           set_rowheight(p_rowheight,false);
@@ -236,19 +239,21 @@ void hk_dsgrid::loaddata(const hk_string& definition)
         hkdebug("hk_dsgrid::loaddata p_automatic_columns==FALSE");
 #endif
         long unsigned int c=0;
-
-	get_tagvalue(definition,"COLUMNSCOUNT",c);
+        xmlNodePtr cols=get_tagvalue(definition,"COLUMNDEFINITIONS");
+        if (cols) cols=cols->xmlChildrenNode;
+	get_tagvalue(cols,"COLUMNSCOUNT",c);
         resize_cols(c);
-        hk_string st;
+        xmlNodePtr st=NULL;
+        hk_string xxx;
         unsigned int i=0;  int v=1;
-        while (get_tagvalue(definition,"HK_DSGRIDCOLUMN",st,v,mastertag)&&i<c)
-        {
+        while ((st=(get_tagvalue(cols,"HK_DSGRIDCOLUMN",xxx,v,mastertag)))&&i<c)
+        {  
 #ifdef HK_DEBUG
             hkdebug("hk_dsgrid::loaddata another column");
 #endif
             p_cols[i]->set_grid(this);
             p_cols[i]->set_datasource(datasource());
-            p_cols[i]->loaddata(st);
+            p_cols[i]->loaddata(st->xmlChildrenNode);
             i++;v++;
         }
     }
@@ -273,6 +278,22 @@ hk_dsgridcolumn* hk_dsgrid::gridcolumn(unsigned int  c)
 }
 
 
+hk_dsgridcolumn* hk_dsgrid::gridcolumn(const hk_string&  c)
+{
+#ifdef HK_DEBUG
+    hkdebug("hk_dsgrid::gridcolumn: ",c);
+    hkdebug("p_numcols=",(int)p_cols.size());
+#endif
+
+    for (unsigned int a=0;a<p_cols.size();++a)
+    {
+        if (p_cols[a]&&p_cols[a]->identifier()==c)
+        return (p_cols[a]);
+    }
+        return NULL;
+}
+
+
 bool hk_dsgrid::datasource_disable(void)
 {
 #ifdef HK_DEBUG
@@ -642,13 +663,19 @@ bool hk_dsgrid::load_table(void)
     hkdebug("hk_dsgrid::load_table");
 #endif
     if (datasource()==NULL) return false;
-    hk_string res=u2l(datasource()->database()->load(datasource()->name(),ft_table));
+    xmlNodePtr res=datasource()->database()->xmlload(datasource()->name(),ft_table);
+    res=get_tagvalue(res,"HK_TABLE");
+    if (!res) return false;
+    res=res->xmlChildrenNode;
     if (!p_presentation)datasource()->set_automatic_data_update(datasource()->database()->is_automatic_data_update());
-    if (res.size()==0)return false;
+    if (!res)return false;
 
-    hk_string g;
-    if (get_tagvalue(res,"HK_DSGRID",g))
+    xmlNodePtr g;
+    if ((g=get_tagvalue(res,"HK_DSGRID")))
+      {
+        g=g->xmlChildrenNode;
         loaddata(g);
+      }
     set_font(hk_font::defaultfontname(),hk_font::defaultfontsize());
 
     return true;
@@ -683,11 +710,12 @@ bool hk_dsgrid::load_view(void)
     hkdebug("hk_dsgrid::load_VIEW");
 #endif
     if (datasource()==NULL) return false;
-    hk_string res=u2l(datasource()->database()->load(datasource()->name(),ft_view));
-    if (res.size()==0)return false;
+    xmlNodePtr res=datasource()->database()->xmlload(datasource()->name(),ft_table);
+    if (!res)return false;
 
-    hk_string g;
-    if (get_tagvalue(res,"HK_DSGRID",g))
+    xmlNodePtr g;
+
+    if ((g=get_tagvalue(res,"HK_DSGRID")))
         loaddata(g);
     set_font(hk_font::defaultfontname(),hk_font::defaultfontsize());
 
