@@ -18,7 +18,7 @@ using namespace std;
 class hk_column;
 /**
  *@short  base class for widgets which show multi column data in a grid.
- *@version $Revision: 1.31 $
+ *@version $Revision: 1.33 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *base class  for widgets which show multi column and multi row data in a grid.
@@ -34,6 +34,7 @@ class hk_dsgrid:public hk_dsvisible
  *@param c number of the column.
  */
         hk_dsgridcolumn* gridcolumn(unsigned int c);
+        hk_dsgridcolumn* gridcolumn(const hk_string& identfier);
 /**
  * returns the number of columns shown in the grid.
  */
@@ -77,7 +78,7 @@ class hk_dsgrid:public hk_dsvisible
 //	bool save_grid(const hk_string& name="",bool ask=true);
         virtual   void  savedata(ostream& s,bool saveall);
         virtual   void savedata(ostream&s );
-        virtual   void loaddata(const hk_string& definition);
+        virtual   void loaddata(xmlNodePtr definition);
         virtual void set_datasource(hk_datasource*);
         list <hk_string>* visible_columns(void);
         list <hk_string>* nonvisible_columns(void);
