@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.27 $
+//$Revision: 1.29 $
 #include "hk_dsgridcolumn.h"
 #include "hk_dsgrid.h"
 #include "hk_dscombobox.h"
@@ -208,13 +208,16 @@ void hk_dsgridcolumn::savedata(ostream& s)
 }
 
 
-void hk_dsgridcolumn::loaddata(const hk_string& definition)
+void hk_dsgridcolumn::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_dsgridcolumn::loaddata");
 #endif
 
-    hk_dsdatavisible::loaddata(definition);
+        xmlNodePtr d=get_tagvalue(definition,"HK_DSDATAVISIBLE");
+    if (d)d=d->xmlChildrenNode;
+
+    hk_dsdatavisible::loaddata(d);
     get_tagvalue(definition,"DISPLAYNAME",p_displayname);
     get_tagvalue(definition,"COLUMNWIDTH",p_columnwidth);
     hk_string c;
@@ -403,8 +406,8 @@ bool hk_dsgridcolumn::is_findstring(unsigned int pos,const hk_string& searchtext
     }
     else
     {
-        int a=where.find(search);
-        if (a>-1) return true;
+        hk_string::size_type a=where.find(search);
+        if (a!=hk_string::npos) return true;
     }
 
     return false;
