@@ -21,7 +21,7 @@ class hk_dsgridcolumnmodeprivate;
 class hk_dsgridcolumnprivate;
 /**
  *@short  structure of a column in a grid
- *@version $Revision: 1.20 $
+ *@version $Revision: 1.21 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *structure of a column in a grid.
@@ -50,7 +50,7 @@ class  hk_dsgridcolumn :public hk_dsdatavisible
         void set_columnwidth(int ,bool registerchange=true);
         int columnwidth(void);
         virtual   void  savedata(ostream& s);
-        virtual   void loaddata(const hk_string& definition);
+        virtual   void loaddata(xmlNodePtr definition);
 
 /**
  *comboboxes need 2 datasources. One (the normal) datasource is set with @ref set_datasource and stores the values in a field.
