@@ -95,13 +95,14 @@ void hk_dsimage::savedata(ostream& s )
     end_mastertag(s,tag);
 }
 
-void hk_dsimage::loaddata(const hk_string& definition)
+void hk_dsimage::loaddata(xmlNodePtr definition)
 {
   hk_dsdatavisible::loaddata(definition);
   get_tagvalue(definition,"IMAGEPATH",p_designdata->p_path);
   get_tagvalue(definition,"ZOOM",p_designdata->p_zoom);
-    hk_string d,buffer;
-    if (get_tagvalue(definition,"LOCALIMAGE",buffer))
+    hk_string d;
+    xmlNodePtr buffer;
+    if ((buffer=get_tagvalue(definition,"LOCALIMAGE")))
     {
       unsigned long size=0;
        if (get_tagvalue(buffer,"LOCALIMAGEDATA",d)
