@@ -32,7 +32,7 @@ hk_dsmodevisibleprivate()
 
 
 
-hk_dsmodevisible::hk_dsmodevisible(hk_presentation* presentation):hk_dsvisible(presentation)
+hk_dsmodevisible::hk_dsmodevisible(hk_presentation* p):hk_dsvisible(p)
 {
    p_private=new hk_dsmodevisibleprivate;
     set_mode(hk_dsmodevisible::viewmode);
