@@ -20,7 +20,7 @@ class hk_dsmodevisible: public hk_dsvisible
 public:
 hk_dsmodevisible(hk_presentation* presentation=NULL);
 virtual ~hk_dsmodevisible();
-        enum            enum_mode {designmode,viewmode};
+        enum            enum_mode {designmode,viewmode,filtermode};
 /**
  * if mode is design then you can define or alter a presentation else
  * the data will be shown
