@@ -16,7 +16,7 @@ using namespace std;
 /**
  *
  *@short  base class for row selectors
- *@version $Revision: 1.9 $
+ *@version $Revision: 1.10 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *  base class for row selectors
@@ -24,6 +24,6 @@ using namespace std;
 class hk_dsrowselector:public hk_dsvisible
 {
     public:
-        hk_dsrowselector(hk_form* form=NULL):hk_dsvisible(form){p_visibletype=rowselector;}
+        hk_dsrowselector(hk_form* f=NULL);
 };
 #endif
