@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.77 $
+//$Revision: 1.81 $
 
 #include "hk_presentation.h"
 #include "hk_database.h"
@@ -303,7 +303,7 @@ p_is_new=false;
 }
 
 
-void    hk_presentation::loaddata(const hk_string& definition)
+void    hk_presentation::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_presentation::loaddata");
@@ -323,12 +323,14 @@ void    hk_presentation::loaddata(const hk_string& definition)
     hk_string value;
     int i=1;
     clear_datasourcelist();
-    while (get_tagvalue(definition,"DATASOURCE",value,i,mastertag))
+    xmlNodePtr v=NULL;
+    while ((v=get_tagvalue(definition,"DATASOURCE",value,i,mastertag)))
     {
+        v=v->xmlChildrenNode;
         hk_datasource* ds=NULL;
-        get_tagvalue(value,"TYPE",buffer2);
+        get_tagvalue(v,"TYPE",buffer2);
         hk_string dsname;
-        get_tagvalue(value,"DATASOURCENAME",dsname);
+        get_tagvalue(v,"DATASOURCENAME",dsname);
         datasourcetype dt=dt_table;
         if (buffer2=="QUERY")  dt=dt_query;
 	else
@@ -338,15 +340,15 @@ void    hk_presentation::loaddata(const hk_string& definition)
         ds=get_datasource(dint);
         if (ds!=NULL)
         {
-            ds->loaddata(value, ( dsname.size()==0|| (dt==dt_table ||dt==dt_view) ));
+            ds->loaddata(v, ( dsname.size()==0|| (dt==dt_table ||dt==dt_view) ));
 	    ds->set_name(dsname,false);
             if (ds->p_dscounter>=p_private->p_counter) p_private->p_counter=ds->p_dscounter+1;
         } else show_warningmessage(hk_translate("hk_presentation::loaddata: Error creating/loading datasource! This is probably a bug"));
         i++;
     }
     //if (p_private->p_datasources.size()==0) show_warningmessage(hk_translate("No datasources defined!")) ;
-    get_tagvalue(definition,"HK_DSVISIBLE",value);
-    hk_dsmodevisible::loaddata(value);
+    v=get_tagvalue(definition,"HK_DSVISIBLE");
+    if (v)hk_dsmodevisible::loaddata(v->xmlChildrenNode);
 p_is_new=false;
 }
 
@@ -681,8 +683,10 @@ return p_private->p_interpretername;
 
 void            hk_presentation::set_name(const hk_string& n)
 {
- if (n!=p_private->p_name)p_is_new=true;
- p_private->p_name=n;
+ hk_string nm=replace_all("/",replace_all(".",n,"_"),"_");
+ if (nm!=p_private->p_name)p_is_new=true;
+ p_private->p_name=nm;
+ widget_specific_set_name();
 }
 hk_string       hk_presentation::name(void) const
 {
@@ -730,3 +734,12 @@ bool hk_presentation::is_subpresentation(void)
   return false;
 }
 
+
+bool hk_presentation::load_module(const hk_string& modulename)
+{
+return interpreter()->load_module(modulename);
+
+}
+
+
+
