@@ -11,6 +11,7 @@
 #include "hk_qbe.h"
 #include "hk_datasource.h"
 #include "hk_database.h"
+#include "hk_dsdatavisible.h"
 #include "hk_connection.h"
 
 class hk_qbeprivate
@@ -158,7 +159,7 @@ void hk_qbe::savedata(ostream& s)
 
 
 
-void hk_qbe::loaddata(const hk_string& definition)
+void hk_qbe::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_qbe::loaddata");
@@ -176,8 +177,8 @@ void hk_qbe::loaddata(const hk_string& definition)
    if (buffer=="DELETE") typebuffer=qt_delete;
    p_private->p_distinct=false;
    get_tagvalue(definition,"DISTINCT",p_private->p_distinct);
-
-   while (get_tagvalue(definition,"QBEDEFINITION",value,i,mastertag))
+    xmlNodePtr v=NULL;
+   while ((v=get_tagvalue(definition,"QBEDEFINITION",value,i,mastertag)))
    {
       hk_string field;
       int table;
@@ -187,10 +188,10 @@ void hk_qbe::loaddata(const hk_string& definition)
       enum_functiontype functiontype=ft_condition;
       hk_string updatevalue;
       vector<hk_string> conditionlist;
-      get_tagvalue(value,"FIELD",field);
-      get_tagvalue(value,"TABLE",table);
-      get_tagvalue(value,"ALIAS",alias);
-      if(get_tagvalue(value,"ORDER",buffer))
+      get_tagvalue(v,"FIELD",field);
+      get_tagvalue(v,"TABLE",table);
+      get_tagvalue(v,"ALIAS",alias);
+      if(get_tagvalue(v,"ORDER",buffer))
           {
 
 	     if (buffer=="ASCENDING") order=ascending;
@@ -198,7 +199,7 @@ void hk_qbe::loaddata(const hk_string& definition)
 	     if (buffer=="DESCENDING") order=descending;
           }
 
-      if (get_tagvalue(value,"FUNCTIONTYPE",buffer))
+      if (get_tagvalue(v,"FUNCTIONTYPE",buffer))
       {
           if (buffer=="GROUP") functiontype=ft_group;
 	  else
@@ -212,12 +213,12 @@ void hk_qbe::loaddata(const hk_string& definition)
 	  else
           if (buffer=="AVERAGE") functiontype=ft_avg;
       }
-      get_tagvalue(value,"UPDATEVALUE",updatevalue);
-      get_tagvalue(value,"SHOW",show);
+      get_tagvalue(v,"UPDATEVALUE",updatevalue);
+      get_tagvalue(v,"SHOW",show);
 
       int c=1;
       hk_string cvalue;
-	while (get_tagvalue(value,"CONDITION",buffer,c))
+	while (get_tagvalue(v,"CONDITION",buffer,c))
 	{
 	  conditionlist.insert(conditionlist.end(),buffer);
 	  ++c;
@@ -328,23 +329,30 @@ hk_string hk_qbe::create_where(void)
 
     if (cl->table>-1)
      {
-
+       hk_string fname;
 	 switch (p_private->p_querytype)
   	  {
   		case qt_update:
   		case qt_delete:
   		  {
-		  /*hk_datasource* ds=get_datasource(cl->table);
-		  if (ds)
-		  where+="\""+ds->name()
-	         +"\".\""+cl->field+"\" "+condi[i];
-		 */
-		 where+="\""+cl->field+"\" "+condi[i];
+		 fname="\""+cl->field+"\" ";
+// 		 where+="\""+cl->field+"\" "+condi[i];
 		  break;
 		  }
-  		default:   where+="\""+unique_shortdatasourcename((cl->table))
-	         +"\".\""+cl->field+"\" "+condi[i];
+  		default:
+  		   fname="\""+unique_shortdatasourcename((cl->table))
+	         +"\".\""+cl->field+"\" ";
+/*  		   where+="\""+unique_shortdatasourcename((cl->table))
+	         +"\".\""+cl->field+"\" "+condi[i];*/
   	  }
+  	  hk_string r=condi[i];
+  	  hk_connection* c=NULL;
+  	  if (database()) c=database()->connection();
+  	  hk_dsdatavisible::parsed_value(r,c);
+  	  cerr <<"r="<<r<<"=";
+  	  r=replace_all("%VALEND%",replace_all("%COLNAME%",r,fname),"");
+  	  cerr <<r<<endl;
+  	  where+=r;
     }
    }
     ++it;
