@@ -33,7 +33,7 @@ class hk_reportprivate;
  * CVS, HTML, XML, Postscript etc. It has all functions you need to create reports in any kind and any format.
  * See also the convenience class @ref hk_reportcvs.
  * @short basic class to create reports
- *@version $Revision: 1.65 $
+ *@version $Revision: 1.66 $
  * @author Horst Knorr (hk_classes@knoda.org)
 
  *
@@ -244,7 +244,7 @@ class hk_report :public hk_presentation
         virtual bool save_report(const hk_string& name="",bool ask=true);
         virtual bool load_report(const hk_string& name="");
         virtual void  savedata(ostream& s);
-        virtual void  loaddata(const hk_string& definition);
+        virtual void  loaddata(xmlNodePtr definition);
 
 /**
  *the default column value will be used as a default when a new data will be created with @ref new_data
