@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.80 $
+//$Revision: 1.81 $
 #include "hk_reportdata.h"
 #include "hk_reportsection.h"
 #include "hk_report.h"
@@ -1146,7 +1146,9 @@ hk_string hk_reportdata::tag_value(int tagnumber, bool& ok)
     {
         case alignright : align="RIGHT";break;
         case aligncenter : align="CENTER";break;
-        default         : align="LEFT";
+        case alignleft         : align="LEFT";break;
+        default:  if (is_numerictype(column())) align="RIGHT";
+        	  else align="LEFT";
     };
 
     return align;
