@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.80 $
+//$Revision: 1.83 $
 #include "hk_reportutils.h"
 #include "hk_reportsectionpair.h"
 #include "hk_datasource.h"
@@ -25,8 +25,8 @@ hk_reporthtml::hk_reporthtml(void):hk_report()
     p_columnbefore="";
     set_recodefunction("Html");
     p_withheader=true;
-    p_pagehead="<!doctype html public \"-//w3c//dtd html 4.0 transitional//en\">\n";
-    p_head="<meta http-equiv=\"Content-Type\" content=\"text/html;charset=iso-8859-1\">\n";
+    p_pagehead="<!doctype html public \"-//w3c//dtd html 4.0 transitional//en\">\n<meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf8\">\n";
+    p_head="";
    hk_reportsectionpair* p_tableheadersectionpair= new_sectionpair();
    hk_reportsectionpair* p_tablesurroundpair= new_sectionpair();
 
@@ -85,10 +85,10 @@ void hk_reporthtml::configure_table(void)
     hk_string trtag="   <TR ";
     hk_string trendtag="</TR>\n";
     trtag+=p_trtag+">";
-    p_beforetablesection->reportsectionpair()->set_columnname(p_groupcolumn);cerr <<"p_groupcolumn: "<<p_groupcolumn<<endl;
+    p_beforetablesection->reportsectionpair()->set_columnname(p_groupcolumn);
     p_beforetablesection->set_unique(true);
     p_beforetablesection->set_automatic_create_data(false);
-    set_tabletag(" WIDTH=\"600\" BORDER=1 CELLSPACING=1");
+    set_tabletag("  BORDER=1 CELLSPACING=1");
 
     p_tableheadersection->reportsectionpair()->set_columnname(p_groupcolumn);
     p_tableheadersection->set_unique(true);
@@ -107,7 +107,7 @@ void hk_reporthtml::configure_table(void)
     p_tableheadersection->set_default_reportdata(buffer);
 
     buffer="<TD ";
-    buffer+=p_tdtag+">";
+    buffer+=p_tdtag+" ALIGN=\"%ALIGN%\">";
     p_datasection->set_default_beforereportdata(buffer);
     p_datasection->set_default_afterreportdata("</TD>");
     p_datasection->set_default_reportdata("%VALUE%");
@@ -221,46 +221,15 @@ void    hk_reporthtml::set_author(const hk_string& a)
 
 void    hk_reporthtml::set_groupcolumn(const hk_string& c)
 {
-    p_groupcolumn=c;cerr <<"set_: "<<p_groupcolumn<<endl;
+    p_groupcolumn=c;
     configure_table();
 }
 
 
 hk_string  recode_html(const hk_string& where,hk_report*)
 {
-    hk_string p_where;
-    p_where=where;
-
-    hk_string benannt[]=
-    {
-        "&nbsp;","&iexcl;","&cent;","&pound;","&curren;","&yen;",
-        "&brvbar;","&sect;","&uml;","&copy;","&ordf;","&laquo;","&not;","&shy;",
-        "&reg;","&macr;","&deg;","&plusmn;","&sup2;","&sup3;","&acute;","&micro;",
-        "&para;","&middot;","&cedil;","&sup1;","&ordm;","&raquo;","&frac14;","&frac12;",
-        "&frac34;","&iquest;","&Agrave;","&Aacute;","&Acirc;","&Atilde;","&Auml;","&Aring;",
-        "&AElig;","&Ccedil;","&Egrave;","&Eacute;","&Ecirc;","&Euml;","&Igrave;","&Iacute;",
-        "&Icirc;","&Iuml;","&ETH;","&Ntilde;","&Ograve;","&Oacute;","&Ocirc;","&Otilde;",
-        "&Ouml;","&times;","&Oslash;","&Ugrave;","&Uacute;","&Ucirc;","&Uuml;","&Yacute;",
-        "&THORN;","&szlig;","&agrave;","&aacute;","&acirc;",
-        "&atilde;","&auml;","&aring;","&aelig;","&ccedil;","&egrave;","&eacute;","&ecirc;",
-        "&euml;","&igrave;","&iacute;","&icirc;","&iuml;","&eth;","&ntilde;","&ograve;",
-        "&oacute;","&ocirc;","&otilde;","&ouml;","&divide;","&oslash;","&ugrave;","&uacute;",
-        "&ucirc;","&uuml;","&yacute;","&thorn;","&yuml;"
-
-    } ;
-
-    char* l= new char[2];
-    l[1]=0;
-    if (p_where.size()==0)p_where="&nbsp;";
-    else
-        for (int k=160;k<256;k++)
-    {
-        l[0]=k;
-        p_where=replace_all(l,p_where,benannt[k-160]);
-    }
-
-    delete[] l;
-    return p_where;
+    
+    return smallstringconversion(l2u(where),"","UTF8");
 
 }
 
