@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.90 $
+//$Revision: 1.92 $
 #include "hk_visible.h"
 #include "hk_presentation.h"
 #include "hk_form.h"
@@ -552,13 +552,13 @@ void hk_visible::savedata(ostream& s )
 }
 
 
-void hk_visible::loaddata(const hk_string& definition)
+void hk_visible::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_visible::loaddata");
 #endif
-    hk_string v;
-    get_tagvalue(definition,"VISIBLETYPE",v);
+    xmlNodePtr v;hk_string b;
+    v=get_tagvalue(definition,"VISIBLETYPE",b);
     get_tagvalue(definition,"LABEL",p_designdata->p_label);
     set_label(p_designdata->p_label);
     if (p_designdata->p_load_presentationnumber)
@@ -569,17 +569,17 @@ void hk_visible::loaddata(const hk_string& definition)
     get_tagvalue(definition,"HEIGHT", p_designdata->p_height);
     get_tagvalue(definition,"BUDDYLABEL",p_designdata->p_buddylabel);
     get_tagvalue(definition,"ISENABLED",p_designdata->p_enabled);
-    if (get_tagvalue(definition,"HK_FONT",v))
+    if ((v=get_tagvalue(definition,"HK_FONT",b)))
     {
-     p_designdata->p_font.loaddata(v);
+     p_designdata->p_font.loaddata(v->xmlChildrenNode);
      set_font(p_designdata->p_font);
     }
     else
     {
-      get_tagvalue(definition,"FONT",v);
+      get_tagvalue(definition,"FONT",b);
     long int pfs;
     get_tagvalue(definition,"FONTSIZE",pfs);
-    set_font(v,pfs);
+    set_font(b,pfs);
 
     }
 
@@ -597,20 +597,19 @@ void hk_visible::loaddata(const hk_string& definition)
     if (get_tagvalue(definition,"TOOLTIP",p_designdata->p_tooltip))
        set_tooltip(p_designdata->p_tooltip,false);
 
-    hk_string col;
-    if (get_tagvalue(definition,"FOREGROUNDCOLOUR",col))
+    xmlNodePtr col;
+    if ((col=get_tagvalue(definition,"FOREGROUNDCOLOUR",b)))
     {
-        p_designdata->p_foregroundcolour.loaddata(col);
+        col=get_tagvalue(col->xmlChildrenNode,"HK_COLOUR");
+        if (col)p_designdata->p_foregroundcolour.loaddata(col->xmlChildrenNode);
         set_foregroundcolour(p_designdata->p_foregroundcolour,false);
     }
-    if (get_tagvalue(definition,"BACKGROUNDCOLOUR",col))
+    if ((col=get_tagvalue(definition,"BACKGROUNDCOLOUR",b)))
     {
-        p_designdata->p_backgroundcolour.loaddata(col);
+        col=get_tagvalue(col->xmlChildrenNode,"HK_COLOUR");
+        if (col)p_designdata->p_backgroundcolour.loaddata(col->xmlChildrenNode);
         set_backgroundcolour(p_designdata->p_backgroundcolour,false);
     }
-//compatibility function for version 0.6.1-test1 - SHOULD BE REMOVED FOR VERSION 1.0
-    get_tagvalue(definition,"PUSH_ACTION",p_designdata->p_clickaction);
-// END compatibility function for version 0.6.1-test1
     get_tagvalue(definition,"CLICK_ACTION",p_designdata->p_clickaction);
     get_tagvalue(definition,"DOUBLECLICK_ACTION",p_designdata->p_doubleclickaction);
     get_tagvalue(definition,"ONCLOSE_ACTION",p_designdata->p_oncloseaction);
@@ -622,6 +621,7 @@ void hk_visible::loaddata(const hk_string& definition)
 }
 
 
+
 void hk_visible::has_changed(bool registerchange,enum_has_changed f)
 {
 #ifdef HK_DEBUG
@@ -1123,6 +1123,10 @@ bool        hk_visible::allow_datachanging(bool force_setting)
     return ((p_presentation && p_presentation->mode()==hk_presentation::designmode)||force_setting||!p_presentation);
 }
 
+void hk_visible::before_presentationmode_changed(void)
+{
+
+}
 
 bool hk_visible::presentationmode_changed(void)
 {
@@ -1131,6 +1135,7 @@ bool hk_visible::presentationmode_changed(void)
    switch (p_presentation->mode())
    {
      	case hk_presentation::designmode : ;
+     	case hk_presentation::filtermode : ;
 							widget_specific_foregroundcolour_changed(foregroundcolour());
     							widget_specific_backgroundcolour_changed(backgroundcolour());
     							widget_specific_label_changed();
@@ -1558,4 +1563,3 @@ int hk_visible::register_tag(const hk_string& tag)
 }
 
 
-
