@@ -40,6 +40,30 @@ hk_firebirdconnection::hk_firebirdconnection(hk_drivermanager* c):hk_connection(
     set_user("sysdba");
     p_connectionsuccessfullyestablished=false;
     p_firebirdhandle=NULL;
+
+const char* sqltokens[]=
+{
+"ACTIVE","ADMIN","AFTER","AS","ASCENDING","AT","AUTO","AUTODDL","BASED","BASENAME","BASE_NAME","BEFORE",
+"BLOB","BLOBEDIT","BUFFER","BY","CACHE","CHECK_POINT_LEN","CHECK_POINT_LENGTH","COMMITTED","COMPILETIME",
+"COMPUTED","CONDITIONAL","CONTAINING","CSTRING","DATABASE","DB_KEY","DEBUG","DESCENDING","DISPLAY","ECHO",
+"EDIT","ENTRY_POINT","EVENT","EXIT","EXTERN","FILE","FILTER","FREE_IT","FUNCTION","GDSCODE","GENERATOR",
+"GEN_ID","GROUP_COMMIT_","GROUP_COMMIT_WAIT","HELP","IN","INACTIVE","INDEX","INIT","INPUT_TYPE",
+"INTERBASE","IS","ISQL","KEYWORDS","KEYWORDS","LC_MESSAGES","LC_TYPE","LENGTH","LEV","LOGFILE",
+"LOG_BUFFER_SIZE","LOG_BUF_SIZE","LONG","MANUAL","MAXIMUM","MAXIMUM_SEGMENT","MAX_SEGMENT","MERGE MESSAGE",
+"MINIMUM","MODULE_NAME","NO","NOAUTO","NUM_LOG_BUFFERS","NUM_LOG_BUFS","ON","OR","OUTPUT_TYPE","OVERFLOW",
+"PAGE","PAGELENGTH","PAGES","PAGE_SIZE","PARAMETER","PASSWORD","PLAN","POST_EVENT","PROTECTED","QUIT",
+"RAW_PARTITIONS","RDB$DB_KEY","RECORD_VERSION","RELEASE","RESERV","RESERVING","RETAIN","RETURN","RETURNING_VALUES",
+"RETURNS","ROLE","RUNTIME","SEGMENT","SHADOW","SHARED","SHELL","SHOW","SINGULAR","SNAPSHOT","SORT","SQLWARNING",
+"STABILITY","STARTING","STARTS","STATEMENT","STATIC","STATISTICS","SUB_TYPE","SUSPEND","TERMINATOR","TO",
+"TRIGGER","TYPE","UNCOMMITTED","VARIABLE","VERSION","WAIT","WAIT_TIME","WEEKDAY","WHILE","YEARDAY"
+};
+   for (unsigned int i=0;i<sizeof(sqltokens)/sizeof(const char*);++i)
+    {
+    p_sqlstatements.push_back(sqltokens[i]);
+    }
+
+
+
 }
 
 
