@@ -57,11 +57,20 @@ bool hk_firebirddatasource::driver_specific_enable(void)
        return false;
       }
 
+     bool p_cancel=false;
+     int max=progressinterval();
 
         try
        {
-        while (datasource_fetch_next_row())
+        int i=1;
+        while (datasource_fetch_next_row() && !p_cancel)
 	 {
+	 if (progressdialog() && (i %15000 ==0))
+	 {
+          p_cancel=progressdialog()(i,max,hk_translate("Executing query ..."));
+	 }
+	 ++i;
+	if (i>max-30000)max+=10000;
 	 }
        }
        catch (std::bad_alloc errormessage)
