@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.5 $
+//$Revision: 1.8 $
 #include "hk_mdbtable.h"
 #include "hk_mdbdatabase.h"
 #include "hk_actionquery.h"
@@ -40,6 +40,8 @@ hk_datasource::enum_datasourcetypes hk_mdbtable::type() const
 
 bool hk_mdbtable::driver_specific_enable(void)
 {
+     bool p_cancel=false;
+     int max=progressinterval();
      if (!datasource_open())
       {
        return false;
@@ -48,8 +50,15 @@ bool hk_mdbtable::driver_specific_enable(void)
 
         try
        {
-        while (datasource_fetch_next_row())
+        int i=1;
+        while (datasource_fetch_next_row() && !p_cancel)
 	 {
+	 if (progressdialog() && (i %15000 ==0))
+	 {
+          p_cancel=progressdialog()(i,max,hk_translate("Executing query ..."));
+	 }
+	 ++i;
+	if (i>max-30000)max+=10000;
 	 }
        }
        catch (std::bad_alloc errormessage)
@@ -130,7 +139,7 @@ void hk_mdbtable::set_columnspecifica(hk_mdbcolumn*col,MdbColumn* c)
 	                col->set_columntype(hk_column::integercolumn);
 			break;
 	case MDB_MONEY:
-	                col->set_columntype(hk_column::integercolumn);
+	                col->set_columntype(hk_column::floatingcolumn);
 			break;
 	case MDB_FLOAT:
 	                col->set_columntype(hk_column::smallfloatingcolumn);
@@ -282,7 +291,6 @@ bool hk_mdbtable::datasource_fetch_next_row(void)
 	      if (coltext) 
 	       {
 	        result=smallstringconversion(replace_all("\x0D\x0A",coltext,"\n"),p_database->databasecharset(),"");
-	        
 	       }
               datarow[j].length=(coltext?result.size()+1:0);
               char* dt=NULL;
