@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_mysqlclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -10,7 +10,7 @@
 // ****************************************************************************
 #ifndef HK_MYSQLCOLUMN
 #define HK_MYSQLCOLUMN
-#include <hk_storagecolumn.h>
+#include "hk_storagecolumn.h"
 class hk_mysqldatasource;
 
 class hk_mysqlcolumn:public hk_storagecolumn
