@@ -289,6 +289,9 @@ bool hk_odbcdatasource::driver_specific_enable(void)
             return false;
 
         }
+     bool p_cancel=false;
+     int max=progressinterval();
+     int i=1;
         if (ret==SQL_SUCCESS)
         {
             SQLSMALLINT num_fields;
@@ -302,9 +305,15 @@ bool hk_odbcdatasource::driver_specific_enable(void)
 // now add data
             try
             {
-                while ((ret=SQLFetch(p_result))==SQL_SUCCESS || ret==SQL_SUCCESS_WITH_INFO)
+                while (((ret=SQLFetch(p_result))==SQL_SUCCESS || ret==SQL_SUCCESS_WITH_INFO) && !p_cancel)
                 {
-                    add_data(num_fields);
+		 if (progressdialog() && (i %15000 ==0))
+		 {
+	          p_cancel=progressdialog()(i,max,hk_translate("Executing query ..."));
+		 }
+		 ++i;
+		 if (i>max-30000)max+=10000;  
+                 add_data(num_fields);
                 }                                 //end fetchdata
             }                                     //end try
             catch (std::bad_alloc errormessage)
