@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.19 $
+//$Revision: 1.21 $
 #include "hk_odbctable.h"
 #include "hk_odbcdatabase.h"
 #include "hk_odbcconnection.h"
@@ -62,7 +62,6 @@ bool hk_odbctable::driver_specific_create_table_now(void)
     query->set_sql(csql.c_str(),csql.size());
     bool result=query->execute();
 
-    if (result) cerr<<"Table created"; else cerr<<"Error: table could not be created";cerr <<endl;
     delete query;
     return result;
 }
@@ -582,7 +581,7 @@ bool hk_odbctable::driver_specific_create_columns(void)
             {
                 col->set_definitionmode(true);
                 hk_string n="nextval(";
-                size_t pos=defaultfield->asstring().find(n);
+                hk_string::size_type pos=defaultfield->asstring().find(n);
                 if(pos!=hk_string::npos)
                 {
                     col->set_columntype(hk_column::auto_inccolumn);
@@ -618,7 +617,7 @@ bool hk_odbctable::driver_specific_create_columns(void)
                 col->set_definitionmode(true);
                 hk_string n="SERIAL";
 		hk_string value=string2upper(defaultfield->asstring());
-                size_t pos=value.find(n);
+                hk_string::size_type pos=value.find(n);
                 if(pos!=hk_string::npos)
                 {
                     col->set_columntype(hk_column::auto_inccolumn);
