@@ -60,7 +60,7 @@ void hk_paradoxdatabase::driver_specific_tablelist(void)
     struct dirent *entry;
 
 p_tablelist.erase(p_tablelist.begin(),p_tablelist.end());
-      hk_string dir= p_url.directory().size()>0? p_url.directory(): p_paradoxconnection->databasepath()+"/"+name();
+      hk_string dir= p_url.directory().size()>0? p_url.url(): p_paradoxconnection->databasepath()+"/"+name();
 
     if ((dp=opendir(dir.c_str()))!=NULL)
     {
@@ -75,7 +75,7 @@ p_tablelist.erase(p_tablelist.begin(),p_tablelist.end());
             if (S_ISREG(statbuf.st_mode))
 	    {
                 hk_string n=entry->d_name;
-  	        size_t p =n.find(".db");
+  	        hk_string::size_type p =n.find(".db");
 		if (p==hk_string::npos)
 		   p =n.find(".DB");
 		if (p!=hk_string::npos)
