@@ -24,6 +24,7 @@ class hk_postgresqldatabase:public hk_database
 
     public:
         hk_postgresqlconnection* connection(void);
+        hk_string systemdateformat(void); 
 
     protected:
         hk_postgresqldatabase(hk_postgresqlconnection*c);
@@ -39,5 +40,6 @@ class hk_postgresqldatabase:public hk_database
     private:
         hk_postgresqlconnection * p_postgresqlconnection;
         list<hk_postgresqldatasource*> p_dsourcelist;
+        hk_string p_systemdateformat;
 } ;
 #endif
