@@ -10,7 +10,7 @@
 // ****************************************************************************
 #ifndef HK_SQLITECONNECTION
 #define HK_SQLITECONNECTION
-#include <sqlite.h>
+#include "sqlite/sqlite.h"
 #include "hk_connection.h"
 #include <list>
 #include <vector>
@@ -38,7 +38,7 @@ class hk_sqliteconnection: public hk_connection
         virtual hk_string drivername(void) const;
         virtual unsigned int    default_tcp_port(void) const;
 virtual        bool    create_database(const hk_string& dbase);
-virtual        bool    delete_database(const hk_string& dbase);
+virtual        bool    delete_database(const hk_string& dbase,enum_interaction c=interactive);
 virtual hk_string mimetype(void) const {return "application/x-sqlite2";}
 
     protected:
