@@ -10,8 +10,8 @@
 // ****************************************************************************
 #ifndef HK_SQLITERESULTQUERY
 #define HK_SQLITERESULTQUERY
-#include <hk_datasource.h>
-#include <hk_sqlitedatasource.h>
+#include "hk_datasource.h"
+#include "hk_sqlitedatasource.h"
 class hk_sqlitedatabase;
 class hk_presentation;
 
