@@ -89,6 +89,7 @@ bool hk_xbaseconnection::server_needs(need_enum t) const
 //         case NEEDS_NOTHING:
 	case NEEDS_NULL_TERMINATED_SQL:
 	case NEEDS_MANUAL_CHARSET:
+	case NEEDS_DIRECTORY_AS_DATABASE:
             return true;
 
         default: return false;
@@ -150,7 +151,7 @@ vector<hk_string>* hk_xbaseconnection::driver_specific_dblist(void)
             if (S_ISDIR(statbuf.st_mode))
 	    {
                 hk_string n=entry->d_name;
-  	        size_t p =n.find(".dbf");
+  	        hk_string::size_type p =n.find(".dbf");
 		if (p==hk_string::npos)
 		   p =n.find(".DBF");
 		if (p==hk_string::npos &&n!="output" &&n!="."&&n!="..")
@@ -202,7 +203,6 @@ bool    hk_xbaseconnection::delete_database(const hk_string& dbase,enum_interact
 
     hk_url url=dbase;
     hk_string filename=url.directory().size()>0?dbase:databasepath()+"/"+dbase;
-    cerr <<"delete database:#"<<filename<<"#"<<endl;
     delete_databasedirectory(filename);
     return true;
 
