@@ -27,8 +27,8 @@ hk_xbasedatasource::hk_xbasedatasource(hk_xbasedatabase* d,hk_presentation* p):h
     p_xbasedatabase=d;
     p_sqlquery=NULL;
     p_currow=0;
-    p_true="1";
-    p_false="0";
+    p_true="Y";
+    p_false="N";
     p_actionquery=new hk_xbaseactionquery(d);
 }
 
@@ -52,12 +52,22 @@ bool hk_xbasedatasource::driver_specific_enable(void)
        cerr<<"hk_xbasedatasource::driver_specific_enable !datasource_open() !!!"<<endl;
        return false;
       } 
- 
+      bool p_cancel=false;
+     int max=progressinterval();
+;
+
       
         try
        {
- 	 while (datasource_fetch_next_row())
+       int i=1;
+  	 while (datasource_fetch_next_row() && !p_cancel)
 	 {
+	 if (progressdialog() && (i %15000 ==0))
+	 {
+          p_cancel=progressdialog()(i,max,hk_translate("Executing query ..."));
+	 }
+	 ++i;
+	if (i>max-30000)max+=10000;
 	 }
        }    
        catch (std::bad_alloc errormessage)
@@ -306,6 +316,7 @@ bool hk_xbasedatasource::datasource_fetch_next_row(void)
 	      const char* coltext=v.getText();
 	      hk_string n;
 	      if (coltext) n=smallstringconversion(coltext,p_database->databasecharset(),"");
+	      cerr <<"n:"<<n<<endl;
               datarow[f].length=(coltext?strlen(n.c_str())+1:0); 
               char* dt=NULL;
               if (coltext)
