@@ -12,20 +12,21 @@ try:
 	import sys,types,time
 	from traceback import *
 	from os.path import *
+	sys.path.append("../python")
 except:
 	print "Main python modules could not be loaded, wrong installation?"
-	exit(1)
+	sys.exit(1)
 try:
 	from hk_classes import *
 except:
 	print "hk_classes module could not be loaded, wrong installation?"
-	exit(1)
+	sys.exit(1)
 
 
 dr=hk_drivermanager()
 if dr==None:
 	print "drivermanager could not be loaded!"
-	exit(1)
+	sys.exit(1)
 
 #general definitions
 successfull_tests=0
@@ -44,33 +45,60 @@ skipped="SKIPPED"
 
 defaultdbname="hkclassestest"
 testtablename="test"
+dependingtablename="depending"
+
+
+
+skip_tests={}
+additional_tests={}
 
 # Definition of the test table
 # columntype,columnname,size,is_primary,is_notnull
 column_definitions= [ 
 [hk_column.auto_inccolumn,"id",4,True,False],
 [hk_column.textcolumn,"text",255,False,False],
+[hk_column.memocolumn,"memo",0,False,False],
 [hk_column.floatingcolumn,"floating",0,False,False],
 [hk_column.smallintegercolumn,"smallint",0,False,False],
 [hk_column.datecolumn,"datecol",0,False,False],
 [hk_column.timecolumn,"timecol",0,False,False],
-[hk_column.datetimecolumn,"dtcol",0,False,False]
+[hk_column.datetimecolumn,"dtcol",0,False,False],
+[hk_column.boolcolumn,"boolcol",0,False,False]
 ]
 
 
 
 #test data for creating and updating tables
-table_columns=["text","smallint","floating","datecol","timecol","dtcol"]
+table_columns=["text","memo","smallint","floating","datecol","timecol","dtcol","boolcol"]
 table_values= [
-["mytext",0,0.0,"05.03.2005","14:35:00","01.01.1999 00:00:00"],
-["mytext2",255,255.75,"07.02.1901","00:01:00","31.01.2005 13:42:04"],
-["mytext3",-255,-255.75,"28.11.2006","03:00:15","24.12.2005 15:03:00"]
+["mytext","mymemo",0,0.0,"05.03.2005","14:35:00","01.01.1999 00:00:00",True],
+["mytext2","mymemo2",255,255.75,"07.02.1901","00:01:00","31.01.2005 13:42:04",False],
+["mytext3","mymemo3",-255,-255.75,"28.11.2006","03:00:15","24.12.2005 15:03:00",True]
 ]
 
 update_values= [
-["myreplacedtext",5,9.1,"25.01.1974","12:00:00","11.08.1912 03:04:05"],
-["myreplacedt2",-2,-8.75,"01.03.1965","01:00:14","16.01.1913 13:24:35"]
+["myreplacedtext","myreplacedmemo1",5,9.1,"25.01.1974","12:00:00","11.08.1912 03:04:05",False],
+["myreplacedt2","myreplacedmemo2",-2,-8.75,"01.03.1965","01:00:14","16.01.1913 13:24:35",True]
 ]
+
+
+dependingcolumn_definitions= [ 
+[hk_column.auto_inccolumn,"id",4,True,False],
+[hk_column.smallintegercolumn,"dep",0,False,False]
+]
+
+dependingtable_columns=["dep"]
+dependingtable_values= [
+[1],[1],[1],[1],
+[2],[2],[2],
+[3],[3]
+]
+
+
+
+
+
+
 #special treatment of login infos
 # drivername:{database,logindatabase,user,password,host}
 login_info={
@@ -94,6 +122,19 @@ def perform_test(driver,tstfunction,functiondata,description):
 	testnumber=testnumber+1
 	if driver not in tested_drivers:
 		tested_drivers.append(driver)
+	
+	if driver in skip_tests:
+		tsts=skip_tests[driver]
+		if tstfunction in tsts:
+			reason="Test skipped intentionally"
+			msg="["+str(testnumber)+"]\tDriver:'"+driver+"': "+description+"..."+skipped
+			skipped_messages.append(msg)
+			skipped_messages.append("\t"+reason)
+			skipped_tests=skipped_tests+1
+			return skipped
+
+	
+	
 	result=failed
 	reason="Unknown"
 	try:
@@ -104,7 +145,7 @@ def perform_test(driver,tstfunction,functiondata,description):
 		#print_tb(sys.exc_info(),5)
 		
 	msg="["+str(testnumber)+"]\tDriver:'"+driver+"': "+description+"..."+result
-	#print msg
+	print msg
 	performed_tests.append(msg)
 
 	if result==failed:
@@ -223,7 +264,7 @@ def open_database(driver,dbname,create=False,deleteexistingdb=False,user="root",
 	con=new_connection(driver)
 	if con==skipped:
 		return skipped
-	if create:
+	if create and (not dbname in con.dblist() and not exists(dbname)):
 		result=create_database(con,dbname,deleteexistingdb)
 		if result!=ok:
 			reason="create_database failed: "+con.last_servermessage()
@@ -234,6 +275,9 @@ def open_database(driver,dbname,create=False,deleteexistingdb=False,user="root",
 		
 		return failed
 	db=con.new_database(dbname)
+	if db==None:
+		reason= "Database could not be created: "+con.last_servermessage()
+		return failed
 	return db
 
 
@@ -256,7 +300,7 @@ def delete_database(con,db):
 
 
 
-def create_table(db,tbl,insert=False):
+def create_table(db,tbl,coldef,values,valuecolumns,insert=False):
 	global reason
 	if not db.connection().server_supports(hk_connection.SUPPORTS_NEW_TABLE):
 		reason="Server does not support creating new tables"
@@ -266,7 +310,7 @@ def create_table(db,tbl,insert=False):
 	table=db.new_table()
 	table.setmode_createtable()
 	table.set_name(tbl)
-	for col in column_definitions:
+	for col in coldef:
 		c=table.new_column()
 		c.set_columntype(col[0])
 		c.set_name(col[1])
@@ -276,7 +320,7 @@ def create_table(db,tbl,insert=False):
 	result=table.create_table_now()
 	if result ==1:
 		if insert:
-			insert_table(table)
+			insert_table(table,values,valuecolumns)
 		return table
 	else:
 		return None
@@ -300,7 +344,7 @@ def delete_table(db,tbl):
 
 
 
-def insert_table(tbl):
+def insert_table(tbl,values,columns):
 	global reason
 	if not tbl.is_enabled():
 		tbl.enable()
@@ -308,16 +352,18 @@ def insert_table(tbl):
 			reason="Table could not be enabled"
 			return failed
 	rownumber=0
-	for row in table_values:
+	for row in values:
 		colid=0
 		tbl.setmode_insertrow()
 		for col in row:
-			c=tbl.column_by_name(table_columns[colid])
+			c=tbl.column_by_name(columns[colid])
 			t=type(col)
 			if t== types.IntType:
 				c.set_asinteger(col)
 			elif t== types.FloatType:
 				c.set_asdouble(col)
+			elif t== types.BooleanType:
+				c.set_asbool(col)
 			else:
 				c.set_asstring(col)
 			colid=colid+1
@@ -353,6 +399,8 @@ def update_table(tbl):
 				c.set_asinteger(col)
 			elif t== types.FloatType:
 				c.set_asdouble(col)
+			elif t== types.BooleanType:
+				c.set_asbool(col)
 			else:
 				c.set_asstring(col)
 			colid=colid+1
@@ -416,6 +464,24 @@ def delete_currentrow(tbl):
 		return failed
 
 
+def create_dependingdatasource(driver,tblname):
+	global dr
+	global reason
+	db=open_database(driver,testdbname(driver))
+	if db==failed or db==skipped:
+		return skipped
+	if (db==None):
+		return failed
+	
+	res=create_table(db,tblname,dependingcolumn_definitions,dependingtable_values,dependingtable_columns,True)
+
+	con=db.connection()
+	del db
+	con.disconnect()
+	del con
+	if res!=None:
+		return ok
+	return failed
 
 
 
@@ -508,7 +574,7 @@ def tst_createtable(driver,data):
 	if (db==None):
 		return failed
 	else:
-		result= create_table(db,data,False)
+		result= create_table(db,data,column_definitions,table_values,table_columns,False)
 		con=db.connection()
 		del db
 		con.disconnect()
@@ -553,7 +619,7 @@ def tst_insertdata(driver,data):
 		reason="Table object could not be created"
 		return skipped
 	table.set_name(data)
-	res=insert_table(table)
+	res=insert_table(table,table_values,table_columns)
 	con=db.connection()
 	del db
 	con.disconnect()
@@ -625,7 +691,7 @@ def tst_deletesinglerow(driver,data):
 	del con
 	return res
 
-def tst_comparedata(driver,data):
+def tst_comparedata(driver,tablename):
 	global dr
 	global reason
 	db=open_database(driver,testdbname(driver))
@@ -636,15 +702,16 @@ def tst_comparedata(driver,data):
 		reason="Table object could not be created"
 		del db
 		return skipped
-	table.set_name(data)
+	table.set_name(tablename)
 	i=0
 	if not table.is_enabled():
 		table.enable()
 
 	if not table.is_enabled():
-		reason="Datasource could not be enabled"
+		reason="Datasource '"+tablename+"' could not be enabled"
 		del db
 		return failed
+	table.goto_first()
  	if len(table_values)!=table.max_rows():
  		reason="different amount of rows. Table has "+str(table.max_rows())+", but should have "+str(len(table_values))+tablecontent(table)
 		del db
@@ -663,14 +730,23 @@ def tst_comparedata(driver,data):
 			if t== types.IntType:
 				if c.asinteger()!=col:
 					reason="Row:"+str(rownumber)+" Integer in column:'"+table_columns[colid]+"' is different\n\t"
-					reason=reason+"Table has '"+c.asinteger()+"', should be '"+col+"'"+tablecontent(table)
+					reason=reason+"Table has '"+str(c.asinteger())+"', should be '"+str(col)+"'"+tablecontent(table)
 					table.disable()
 					del db
 					return failed
 			elif t== types.FloatType:
 				if c.asdouble()!=col:
 					reason="Row:"+str(rownumber)+" Float in column:'"+table_columns[colid]+"' is different\n\t"
-					reason=reason+"Table has '"+c.asdouble()+"', should be '"+col+"'"+tablecontent(table)
+					print reason
+					reason=reason+"Table has '"+str(c.asdouble())+"', should be '"+str(col)+"'"+tablecontent(table)
+					table.disable()
+					del db
+					return failed
+			elif t== types.BooleanType:
+				if c.asinteger()!=col:
+					reason="Row:"+str(rownumber)+" Bool in column:'"+table_columns[colid]+"' is different\n\t"
+					print reason
+					reason=reason+"Table has '"+str(c.asbool())+"', should be '"+str(col)+"'"+tablecontent(table)
 					table.disable()
 					del db
 					return failed
@@ -694,7 +770,7 @@ def tst_comparedata(driver,data):
 
 
 
-def tst_compareupdatedata(driver,data):
+def tst_compareupdatedata(driver,tablename):
 	global dr
 	global reason
 	db=open_database(driver,testdbname(driver))
@@ -705,7 +781,7 @@ def tst_compareupdatedata(driver,data):
 		reason="Table object could not be created"
 		del db
 		return skipped
-	table.set_name(data)
+	table.set_name(tablename)
 	i=0
 	table.disable()
 	table.set_sorting("\"id\"")
@@ -713,7 +789,7 @@ def tst_compareupdatedata(driver,data):
 		table.enable()
 
 	if not table.is_enabled():
-		reason="Datasource could not be enabled"
+		reason="Datasource '"+tablename+"' could not be enabled"
 		del db
 		return failed
  	if len(update_values)>table.max_rows():
@@ -733,14 +809,21 @@ def tst_compareupdatedata(driver,data):
 			if t== types.IntType:
 				if c.asinteger()!=col:
 					reason="Row:"+str(rownumber)+" Integer in column:'"+table_columns[colid]+"' is different\n\t"
-					reason=reason+"Table has '"+c.asinteger()+"', should be '"+col+"'"+tablecontent(table)
+					reason=reason+"Table has '"+str(c.asinteger())+"', should be '"+str(col)+"'"+tablecontent(table)
 					table.disable()
 					del db
 					return failed
 			elif t== types.FloatType:
 				if c.asdouble()!=col:
 					reason="Row:"+str(rownumber)+" Float in column:'"+table_columns[colid]+"' is different\n\t"
-					reason=reason+"Table has '"+c.asdouble()+"', should be '"+col+"'"+tablecontent(table)
+					reason=reason+"Table has '"+str(c.asdouble())+"', should be '"+str(col)+"'"+tablecontent(table)
+					table.disable()
+					del db
+					return failed
+			elif t== types.BooleanType:
+				if c.asbool()!=col:
+					reason="Row:"+str(rownumber)+" Bool in column:'"+table_columns[colid]+"' is different\n\t"
+					reason=reason+"Table has '"+str(c.asbool())+"', should be '"+str(col)+"'"+tablecontent(table)
 					table.disable()
 					del db
 					return failed
@@ -761,10 +844,120 @@ def tst_compareupdatedata(driver,data):
 	del con
 	return ok
 
+filename='hktst.csv'
+coldel="\t"
+def create_cvsfile():
+	file=open(filename,'w')
+	if file==None:
+		reason="csv file could not be created for writing"
+		return failed
+	
+	c=0
+	for colname in table_columns:
+		if c>0:
+			file.write(coldel)
+		file.write('"'+colname+'"')
+		c=c+1
+	file.write("\n")
+	
+	for row in table_values:
+		colid=0
+		for col in row:
+			if colid>0:
+				file.write(coldel)
+			t=type(col)
+			if t== types.IntType:
+				file.write(str(col))
+			elif t== types.FloatType:
+				file.write(str(col))
+			elif t== types.BooleanType:
+				file.write(str(col))
+			else:
+				file.write('"'+str(col)+'"')
+			colid=colid+1
+		file.write("\n")
+	file.close()
+	
+
+def tst_importcsv(driver,data):
+	global dr
+	global reason
+	create=True
+ 	db=open_database(driver,testdbname(driver),create)
+ 	if db==failed or db==skipped:
+		return skipped
+	i=hk_importcsv()
+	t=db.new_table()
+# 	t.set_print_sqlstatements(True)
+	t.set_name(testtablename)
+	i.set_datasource(t)
+	i.set_filename(filename)
+	i.set_firstrow_contains_fieldnames(True)
+	i.set_overwrite_table(True)
+	
+
+	
+	i.set_filedefinition('"',coldel,"\n","D.M.Y h:m:s","D.M.Y","h:m:s","","C")
+	
+	if not i.execute(hk_class.noninteractive):
+		reason="execute failed"
+		return failed
+	t.disable()
+	del t
+	del i
+	res=tst_comparedata(driver,testtablename)
+	if res !=ok:
+		return res
+# 	res=tst_deletedatabase(driver,testdbname(driver))
+# 	if res!=ok:
+# 		return res
+	return ok
 
 
-def perform_readwritetests(driver):
+
+
+
+def tst_dependingdatasource(driver,data):
+	global dr
+	global reason
+ 	db=open_database(driver,testdbname(driver))
+ 	if db==failed or db==skipped:
+		return skipped
+	res=create_dependingdatasource(driver,dependingtablename)
+	if res==failed:
+		return failed
+	print db.tablelist()
+	master=db.new_table(testtablename)
+	slave=db.new_table(dependingtablename)
+	slave.set_depending_on(master)
+	slave.add_depending_fields("dep","id")
+	if not master.enable():
+		reason="Master table could not be enabled"
+		return failed
+	if not slave.is_enabled():
+		reason="Slave table is not enabled"
+		return failed
+	col=master.column_by_name("id")
+	if col==None:
+		reason="Master id column not found"
+		return failed
+	for i in xrange(2):
+		v=dependingtable_values.count([col.asinteger()])
+		if slave.max_rows()!=v:
+			reason="Different amount of rows, Slave has "+str(slave.max_rows())+", but should have "+str(v)
+			return failed
+		master.goto_next()
+	master.disable()
+	slave.disable()
+	return ok
+
+
+def perform_fulldrivertest(driver):
+	global reason
 	data=""
+ 	result=perform_test(driver,tst_connection,data,"connection test")
+	if result==failed:
+		return
 	result=perform_test(driver,tst_createdatabase,data,"create database test")
  	result=perform_test(driver,tst_opendatabase,testdbname(driver),"open existing database test")
  	result=perform_test(driver,tst_createtable,testtablename,"create table test")
@@ -772,40 +965,53 @@ def perform_readwritetests(driver):
 	result=perform_test(driver,tst_comparedata,testtablename,"compare inserted data test")
 	if result!=ok:
 		return
-	
 	result=perform_test(driver,tst_updatedata,testtablename,"update data test")
 	result=perform_test(driver,tst_compareupdatedata,testtablename,"compare updated data test")
+	if result!=ok:
+		return
+	if driver in additional_tests:
+		tsts=additional_tests[driver]
+		if tst_dependingdatasource in tsts:
+			result=perform_test(driver,tst_dependingdatasource,data,"depending datasource test")
+			if result==failed:
+				return
+		if tst_importcsv in tsts:
+			result=perform_test(driver,tst_importcsv,data,"importcsv test")
+			if result==failed:
+				return
+	
+	
 	result=perform_test(driver,tst_deletemultiplerows,testtablename,"delete multiple rows test")
 	result=perform_test(driver,tst_deletesinglerow,testtablename,"delete single row test")
 	result=perform_test(driver,tst_deletetable,testtablename,"delete table test")
 	result=perform_test(driver,tst_deletedatabase,testdbname(driver),"delete database test")
-
-
-
-def perform_fulldrivertest(driver):
-	data=""
- 	result=perform_test(driver,tst_connection,data,"connection test")
-	if result==failed:
-		return
-	con=new_connection(driver)
-	if con.server_supports(hk_connection.SUPPORTS_NEW_DATABASE):
-		con.disconnect()
-		perform_readwritetests(driver)
-	del con
 	
 	
-def perform_readonlydrivertest(driver,database,table):
-	database="/home/horst/encoding.mdb"
-	result=perform_test(driver,tst_opendatabase,database,"open database test")
 
-def perform_hk_classestests(driver):
-	print "hk_classestests"
+
 
 
 #define performed tests
+writetests=[tst_insertdata,tst_comparedata,tst_updatedata,tst_compareupdatedata,tst_deletesinglerow,tst_deletemultiplerows,tst_deletetable,tst_deletedatabase]
+createtests=[tst_createdatabase,tst_createtable,]
+skip_tests["dbase"]=[tst_compareupdatedata]
+skip_tests["mdb"]=createtests+writetests
+skip_tests["postgres"]=[tst_deletedatabase]
 
+hkclassestests=[tst_importcsv,tst_dependingdatasource]
+additional_tests["sqlite3"]=hkclassestests
+additional_tests["sqlite2"]=hkclassestests
+additional_tests["mysql"]=hkclassestests
+additional_tests["postgres"]=hkclassestests
+additional_tests["dbase"]=[tst_importcsv]
+#additional_tests["paradox"]=[tst_importcsv]
+
+
+create_cvsfile()
+#perform_fulldrivertest("dbase")
 for driver in dr.driverlist():
-	perform_fulldrivertest(driver)
-
+	if driver!="xbase":
+		perform_fulldrivertest(driver)
+#perform_fulldrivertest("paradox")
 #show statistics
 print_teststatistic()
