@@ -12,6 +12,7 @@ static struct argp_option options[] =
     {"aftertable",12,"AFTERTABLETEXT",0,"text displayed after the table",0},
     {"headsection",13,"HEADSECTION",0,"meta data in the <HEAD></HEAD> section",0},
     {"groupcolumn",14,"COLUMNNAME",0,"for each group will be created an extra table",0},
+    {"tabletags",'t',"TABLETAGS",0,"The tags of the <table> statement, e.g.  BORDER=1 CELLSPACING=1",0},
     {0,0,0,0,0,0}
 
 };
@@ -23,6 +24,7 @@ class htmlargumentclass :public argumentclass
         hk_string datasource;
         hk_string beforetable,aftertable,head;
 	hk_string groupcolumn;
+	hk_string tabletag;
         datasourcetype dstype;
         bool fieldname_asattribute;
 };
@@ -45,6 +47,8 @@ static error_t parse_options (int key,char* arg, struct argp_state* state)
         break;
         case 14 : arguments->groupcolumn=arg;
         break;
+        case 't' : arguments->tabletag=arg;
+        break;
         case ARGP_KEY_ARG:
         {
             if (state->arg_num!=0)
@@ -115,6 +119,9 @@ int main(int argc, char** argv)
         exit(1);
     }
 
+
+    
+    
     hk_database* db=c->new_database(arguments.database);
     hk_reporthtml* r= new hk_reporthtml();
     if (!r)
@@ -132,9 +139,11 @@ int main(int argc, char** argv)
     r->set_beforetable(arguments.beforetable);
     r->set_aftertable(arguments.aftertable);
     r->set_betweenheadtags(arguments.head);
-    r->set_groupcolumn(arguments.groupcolumn);cerr <<"commandlinegroupcolumn: "<<arguments.groupcolumn <<endl;
+    r->set_groupcolumn(arguments.groupcolumn);//cerr <<"commandlinegroupcolumn: "<<arguments.groupcolumn <<endl;
     r->set_filename("",false);
     r->set_use_standard_storagepath(false);
+    if (arguments.tabletag.size()==0) arguments.tabletag="BORDER=1 CELLSPACING=1";
+    r->set_tabletag(arguments.tabletag);
 
     if (r->datasource() && arguments.filter.size())
     {
